#!/bin/bash

ret=0
ok=0
failed=0
total=0

function increment
{
	if [ $1 -gt 0 ]; then
		ret=$((ret+$1))
		failed=$((failed+1))
		echo "========================================"
		echo "Test Failed..."
		echo ""
	else
		ok=$((ok+1))
		echo "========================================"
		echo "Test Success..."
		echo ""
	fi
	total=$((total+1))
}

#Local Tests
echo "Backup using 'local' config"
op5-backup -c /opt/op5-backup/test/local.conf
increment $?

echo "Backup using 'local' override"
op5-backup -m default -o -t local -d /tmp/backup-local-override
increment $?

echo "Backup Migrate using 'local' override"
op5-backup -m charch -o -t local -d /tmp/backup-migrate-local-override -- -sysconfig
increment $?

#SCP Tests
if [ "x$USER" == "x" ]; then
	USER="root"
fi

if [ "$USER" == "root" ]; then
	echo "Force override ci env \$HOME dir"
	HOME="/root"
fi

if [ -e $HOME/.ssh ]; then
  mv $HOME/.ssh $HOME/.ssh-pretest
fi
echo "Generate key for $USER to: $HOME/.ssh/"
ssh-keygen -q -t rsa -N "" -f $HOME/.ssh/id_rsa
cat $HOME/.ssh/id_rsa.pub >> $HOME/.ssh/authorized_keys
chmod 600 $HOME/.ssh/authorized_keys
ssh -q -o StrictHostKeyChecking=no localhost exit 2>&1>/dev/null

echo "Backup using 'scp' config"
op5-backup -c /opt/op5-backup/test/scp.conf
increment $?

echo "Backup using 'scp' override"
op5-backup -m default -o -t scp -s localhost -u $USER -d /tmp/backup-scp-override
increment $?

echo "Backup Migrate using 'scp' override"
op5-backup -m charch -o -t scp -s localhost -u $USER -d /tmp/backup-migrate-scp-override -- -sysconfig
increment $?

# Cleanup SCP
if [ -e $HOME/.ssh -a -e $HOME/.ssh-pretest ]; then
	echo "Cleanup ssh config"
	rm -rf $HOME/.ssh
	mv $HOME/.ssh-pretest $HOME/.ssh
fi

echo "Tests: ${total}, OK: ${ok}, FAILED: ${failed}"
exit $ret
